/**
 *	@file	GetPixelsSettingsContainer.h
 *	@author	ENDO
 */

#ifndef __GETPIXELSSETTINGSCONTAINER_H__
#define __GETPIXELSSETTINGSCONTAINER_H__

#include <CAknMemorySelectionSettingItem.h>	// for CAknMemorySelectionDialog::TMemory.

class TGetPixelsSettings
	{
public:
	inline TGetPixelsSettings(void) :
		iImageFormat(ESettingsImageFormatPng),
		iSaveLocation(CAknMemorySelectionDialog::EPhoneMemory),
		iTriggerKey(ESettingsTriggerKeyEditPlusOK),
		iTriggerEvent(ESettingsTriggerEventNone),
		iDelayTime(0),
		iConfirmationNote(EFalse),
		iVibrationNotification(EFalse)
		{
		};

public:
	TInt iImageFormat;
	CAknMemorySelectionDialog::TMemory iSaveLocation;
	TBuf<KMaxSavedDirectoryNameLength> iSavedDirectoryName;
	TBuf<KMaxSavedFileNameLength> iSavedFileName;
	TInt iTriggerKey;
	TInt iTriggerEvent;
	TInt iDelayTime;
	TBool iConfirmationNote;
	TBool iVibrationNotification;
	};

class MGetPixelsSettingItemListObserver
	{
public:
	virtual void NotifyEditItemL(TInt aIndex, TBool aCalledFromMenu) = 0;
	};

class CAknSettingItem;
class CGetPixelsSettingItemList : public CAknSettingItemList
	{
public:
	CGetPixelsSettingItemList(MGetPixelsSettingItemListObserver& aObserver, TGetPixelsSettings& aSettings);

public:
	// from CAknSettingItemList.
	CAknSettingItem* CreateSettingItemL(TInt aIdentifier);
	void EditItemL(TInt aIndex, TBool aCalledFromMenu);

private:
	// from CAknSettingItemList.
	void SizeChanged(void);

private:
	MGetPixelsSettingItemListObserver& iObserver;
	TGetPixelsSettings& iSettings;
	};

class CGetPixelsSettings;
class CGetPixelsAppUi;
class CGetPixelsSettingsContainer : public CCoeControl, public MGetPixelsSettingItemListObserver
	{
public:
	static CGetPixelsSettingsContainer* NewL(const TRect& aRect);
	virtual ~CGetPixelsSettingsContainer();

private:
	CGetPixelsSettingsContainer(void);
	void ConstructL(const TRect& aRect);

public:
	void ChangeSelectedItemL(void);
	void ReadSettingsFromModelL(const CGetPixelsSettings& aModel);
	void WriteSettingsToModelL(CGetPixelsSettings& aModel) const;

private:
	// from CCoeControl.
	TInt CountComponentControls(void) const;
	CCoeControl* ComponentControl(TInt aIndex) const;
	TKeyResponse OfferKeyEventL(const TKeyEvent& aKeyEvent, TEventCode aType);

public:
	// from MGetPixelsSettingItemListObserver.
	void NotifyEditItemL(TInt aIndex, TBool aCalledFromMenu);

private:
	CGetPixelsSettingItemList* iSettingItemList;
	TGetPixelsSettings iSettings;
	CGetPixelsAppUi& iAppUi;
	};

#endif // __GETPIXELSSETTINGSCONTAINER_H__
