/**
 *	@file	ImageSaver.h
 *	@author	ENDO
 */

#ifndef __IMAGESAVER_H__
#define __IMAGESAVER_H__

#include <e32base.h>	// for CActive.

class MImageSaverObserver
	{
public:
	virtual void NotifyCompletion(TInt aStatus) = 0;
	};

class CFbsBitmap;
class RFs;
class CImageEncoder;
class CFrameImageData;
class CImageSaver : public CActive
	{
public:
	static CImageSaver* NewL(RFs& aFs, MImageSaverObserver& aObserver);
	virtual ~CImageSaver();

private:
	CImageSaver(RFs& aFs, MImageSaverObserver& aObserver);
	void ConstructL(void);

private:
	// for CActive.
	void RunL(void);
	void DoCancel(void);

public:
	void SaveFileL(const CFbsBitmap& aBitmap, const TDesC& aFileName, TBool aEnableThread, TUid aImageType = KNullUid, TUid aImageSubType = KNullUid, TUid aEncoderUid = KNullUid);

	template<class T> inline void AppendFrameDataL(const T& aEntry);
	template<class T> inline void AppendImageDataL(const T& aEntry);
	void ResetFrameImageDataL(void);

	inline TBool IsBusy(void) const	{return IsActive();};

private:
	RFs& iFs;
	MImageSaverObserver& iObserver;

	CImageEncoder* iImageEncoder;
	CFrameImageData* iFrameImageData;
	};

template<class T> inline void CImageSaver::AppendFrameDataL(const T& aEntry)
	{
	T* frameData = new(ELeave) T;
	CleanupStack::PushL(frameData);

	*frameData = aEntry;

	User::LeaveIfError(iFrameImageData->AppendFrameData(frameData));
	CleanupStack::Pop(frameData);
	}

template<class T> inline void CImageSaver::AppendImageDataL(const T& aEntry)
	{
	T* imageData = new(ELeave) T;
	CleanupStack::PushL(imageData);

	*imageData = aEntry;

	User::LeaveIfError(iFrameImageData->AppendImageData(imageData));
	CleanupStack::Pop(imageData);
	}

#endif	// __IMAGESAVER_H__
