/**
 *	@file	GetPixelsMainContainer.cpp
 *	@author	ENDO
 */

#include <e32base.h>

#include <aknsbasicbackgroundcontrolcontext.h>
								// for CAknsBasicBackgroundControlContext.
#include <aknsskininstance.h>	// for MAknsSkinInstance.
#include <aknsutils.h>			// for AknLayoutUtils.
#include <aknsdrawutils.h>		// for AknsDrawUtils.

#include "GetPixelsAppUi.h"
#include "GetPixelsMainContainer.h"

CGetPixelsMainContainer* CGetPixelsMainContainer::NewL(const TRect& aRect, CGetPixelsAppUi& aAppUi)
	{
	CGetPixelsMainContainer* self = new(ELeave) CGetPixelsMainContainer(aRect, aAppUi);
	CleanupStack::PushL(self);
	self->ConstructL(aRect, aAppUi);
	CleanupStack::Pop(self);
	return self;
	}

CGetPixelsMainContainer::CGetPixelsMainContainer(const TRect& /* aRect */, CGetPixelsAppUi& aAppUi) :
	iAppUi(aAppUi)
	{
	}

void CGetPixelsMainContainer::ConstructL(const TRect& aRect, CGetPixelsAppUi& /* aAppUi */)
	{
	CreateWindowL();
	SetRect(aRect);
	iBackground = CAknsBasicBackgroundControlContext::NewL(KAknsIIDQsnBgAreaMain, Rect(), EFalse);
	ActivateL();

	iDrawingRect = aRect;
	}

CGetPixelsMainContainer::~CGetPixelsMainContainer()
	{
	delete iBackground;
	}

void CGetPixelsMainContainer::Draw(const TRect& /* aRect */) const
	{
	CWindowGc& gc = SystemGc();
	const TRect rect = Rect();

	const TDesC& filePath = iAppUi.CapturedImageFilePath();
	const CFbsBitmap* bitmap = iAppUi.CapturedBitmap();

	if (bitmap != NULL && iDrawingRect != bitmap->SizeInPixels())
		{
		iDrawingRect.SetRect(TPoint(0, 0), TSize(bitmap->SizeInPixels().iWidth / 2, bitmap->SizeInPixels().iHeight / 2));
		iDrawingRect.Move(TPoint((rect.Width() - iDrawingRect.Width()) / 2, (rect.Height() - iDrawingRect.Height()) / 2));
		}

	MAknsSkinInstance* skin = AknsUtils::SkinInstance();
	AknsDrawUtils::Background(skin, iBackground, this, gc, rect);

	if (bitmap != NULL && bitmap->Handle() != 0 && filePath.Length() > 0)
		{
		gc.DrawBitmap(iDrawingRect, bitmap);
		}
	else
		{
		gc.Clear(iDrawingRect);
		}

		{
		TRect grownRect(iDrawingRect);
		grownRect.Grow(1, 1);
		gc.DrawRect(grownRect);
		}

	if (filePath.Length() > 0)
		{
		TRect shrunkRect(rect);
		shrunkRect.Shrink(4, 4);
		const TParsePtrC parser(filePath);
		gc.UseFont(iCoeEnv->NormalFont());
		gc.DrawText(parser.NameAndExt(), shrunkRect, iCoeEnv->NormalFont()->HeightInPixels());
		gc.DiscardFont();
		}
	}
