/**
 *	@file	GetPixelsSettingsContainer.cpp
 *	@author	ENDO
 */

#include <e32base.h>
#include <sacls.h>		// for KUidChargerStatus.

#include <stringloader.h>
#include <aknsettingitemlist.h>				// for CAknSettingItemList.
#include <akntextsettingpage.h>				// for CAknTextSettingPage.
#include <aknnotewrappers.h>				// for CAknInformationNote.
#include <caknmemoryselectionsettingitem.h>	// for CAknMemorySelectionDialog::TMemory.

#include <GetPixels.rsg>
#include "GetPixels.hrh"
#include "GetPixelsSettingsContainer.h"
#include "GetPixelsSettings.h"
#include "GetPixelsAppUi.h"
#include "GetPixelsUtilities.h"
#include "MyAssert.h"

LOCAL_D const TUint KTableKeyScanCodes[] =
	{
	EStdKeyDevice3,			// "OK"
	static_cast<TInt>('0'),	// "0"
	static_cast<TInt>('*'),	// "*"
	EStdKeyHash,			// "#"
	};

LOCAL_D const TInt32 KTableUidValueSystemEvents[] =
	{
	KNullUidValue,
	KUidChargerStatusValue,
	};

CGetPixelsSettingsContainer* CGetPixelsSettingsContainer::NewL(const TRect& aRect)
	{
	CGetPixelsSettingsContainer* self = new(ELeave) CGetPixelsSettingsContainer;
	CleanupStack::PushL(self);
	self->ConstructL(aRect);
	CleanupStack::Pop(self);
	return self;
	}

void CGetPixelsSettingsContainer::ConstructL(const TRect& aRect)
	{
	CreateWindowL();
	iSettingItemList = new(ELeave) CGetPixelsSettingItemList(*this, iSettings);
	iSettingItemList->SetMopParent(this);
	iSettingItemList->ConstructFromResourceL(R_GETPIXELS_SETTINGITEMLIST_SETTINGS);
	SetRect(aRect);
	ActivateL();
	}

CGetPixelsSettingsContainer::CGetPixelsSettingsContainer(void) :
	iAppUi(*reinterpret_cast<CGetPixelsAppUi*>(CCoeEnv::Static()->AppUi()))
	{
	}

CGetPixelsSettingsContainer::~CGetPixelsSettingsContainer()
	{
	delete iSettingItemList;
	}

TInt CGetPixelsSettingsContainer::CountComponentControls(void) const
	{
	return 1;
	}

CCoeControl* CGetPixelsSettingsContainer::ComponentControl(TInt aIndex) const
	{
	switch (aIndex)
		{
	case 0:
		return iSettingItemList;
		/*NOTREACHED*/
		break;

	default:
		return NULL;
		/*NOTREACHED*/
		break;
		}
	}

TKeyResponse CGetPixelsSettingsContainer::OfferKeyEventL(const TKeyEvent& aKeyEvent, TEventCode aType)
	{
	if (iSettingItemList != NULL)
		{
		return iSettingItemList->OfferKeyEventL(aKeyEvent, aType);
		}

	return EKeyWasNotConsumed;
	}

void CGetPixelsSettingsContainer::ChangeSelectedItemL(void)
	{
	MY_ASSERT(iSettingItemList != NULL);
	iSettingItemList->EditItemL(iSettingItemList->ListBox()->CurrentItemIndex(), ETrue);
	}

void CGetPixelsSettingsContainer::ReadSettingsFromModelL(const CGetPixelsSettings& aModel)
	{
	TInt i;

	// Image format
	if (aModel.ImageFormat() == KImageTypePNGUid)
		{
		iSettings.iImageFormat = ESettingsImageFormatPng;
		}
	else if (aModel.ImageFormat() == KImageTypeBMPUid)
		{
		iSettings.iImageFormat = ESettingsImageFormatBmp;
		}
	else if (aModel.ImageFormat() == KImageTypeMBMUid)
		{
		iSettings.iImageFormat = ESettingsImageFormatMbm;
		}
	else if (aModel.ImageFormat() == KImageTypeJPGUid)
		{
		iSettings.iImageFormat = ESettingsImageFormatJpeg;
		}

	// Save location
	iSettings.iSaveLocation = (aModel.EnableSaveToExternal()) ?
		CAknMemorySelectionDialog::EMemoryCard : CAknMemorySelectionDialog::EPhoneMemory;

	// Saved directory name
	iSettings.iSavedDirectoryName = aModel.SavedDirectoryName();

	// Saved file name
	iSettings.iSavedFileName = aModel.SavedFileName();

	// Trigger key
	for (i = 0; i < static_cast<TInt>(sizeof(KTableKeyScanCodes) / sizeof(KTableKeyScanCodes[0])); i++)
		{
		if (aModel.TriggerKeyScanCode() == KTableKeyScanCodes[i])
			{
			iSettings.iTriggerKey = i;
			break;
			}
		}

	// Trigger event
	for (i = 0; i < static_cast<TInt>(sizeof(KTableUidValueSystemEvents) / sizeof(KTableUidValueSystemEvents[0])); i++)
		{
		if (aModel.TriggerSystemEvent().iUid == KTableUidValueSystemEvents[i])
			{
			iSettings.iTriggerEvent = i;
			break;
			}
		}

	// Delay time
	iSettings.iDelayTime = aModel.DelayTime() / 1000;

	// Confirmation note
	iSettings.iConfirmationNote = aModel.EnableConfirmationNote();

	// Vibration notification
	iSettings.iVibrationNotification = aModel.EnableVibrationNotification();

	iSettingItemList->LoadSettingsL();
	}

void CGetPixelsSettingsContainer::WriteSettingsToModelL(CGetPixelsSettings& aModel) const
	{
	TInt ret;

	iSettingItemList->StoreSettingsL();

	// Image format
	switch (iSettings.iImageFormat)
		{
	case ESettingsImageFormatPng:
		ret = aModel.SetImageFormat(KImageTypePNGUid);
		MY_ASSERT(ret == KErrNone);
		break;
	case ESettingsImageFormatBmp:
		ret = aModel.SetImageFormat(KImageTypeBMPUid);
		MY_ASSERT(ret == KErrNone);
		break;
	case ESettingsImageFormatMbm:
		ret = aModel.SetImageFormat(KImageTypeMBMUid);
		MY_ASSERT(ret == KErrNone);
		break;
	case ESettingsImageFormatJpeg:
		ret = aModel.SetImageFormat(KImageTypeJPGUid);
		MY_ASSERT(ret == KErrNone);
		break;
	default:
		MY_ASSERT(EFalse);
		break;
		}

	// Save location
	ret = aModel.SetEnableSaveToExternal((iSettings.iSaveLocation != CAknMemorySelectionDialog::EPhoneMemory));
	MY_ASSERT(ret == KErrNone);

	// Saved directory name
	ret = aModel.SetSavedDirectoryName(iSettings.iSavedDirectoryName);
	MY_ASSERT(ret == KErrNone);

	// Saved file name
	ret = aModel.SetSavedFileName(iSettings.iSavedFileName);
	MY_ASSERT(ret == KErrNone);

	// Trigger key
	ret = aModel.SetTriggerKeyScanCode(KTableKeyScanCodes[iSettings.iTriggerKey]);
	MY_ASSERT(ret == KErrNone);

	// Trigger event
	ret = aModel.SetTriggerSystemEvent(TUid::Uid(KTableUidValueSystemEvents[iSettings.iTriggerEvent]));
	MY_ASSERT(ret == KErrNone);

	// Delay time
	ret = aModel.SetDelayTime(iSettings.iDelayTime * 1000);
	MY_ASSERT(ret == KErrNone);

	// Confirmation note
	ret = aModel.SetEnableConfirmationNote(iSettings.iConfirmationNote);
	MY_ASSERT(ret == KErrNone);

	// Vibration notification
	ret = aModel.SetEnableVibrationNotification(iSettings.iVibrationNotification);
	MY_ASSERT(ret == KErrNone);
	}

void CGetPixelsSettingsContainer::NotifyEditItemL(TInt aIndex, TBool aCalledFromMenu)
	{
	switch (aIndex)
		{
	case ESettingsImageSetting:
		iAppUi.HandleCommandL(ECommandSwitchToImageSettingsView);
		return;
		/*NOTREACHED*/
		break;

	case ESettingsSavedDirectoryName:
	case ESettingsSavedFileName:
			{
			TFileName tmpFilePath;

			for (;;)
				{
				TRAPD(ret, GetPixelsUtilities::GetSavedFilePathL(tmpFilePath,
						_L("C:\\"), iSettings.iSavedDirectoryName, iSettings.iSavedFileName, _L(".tmp")));
				if (ret == KErrNone && CEikonEnv::Static()->FsSession().IsValidName(tmpFilePath))
					{
					break;
					}

					{
					HBufC* noteText = StringLoader::LoadLC(R_GETPIXELS_TEXT_BAD_FILEPATH);
					CAknInformationNote* note = new(ELeave) CAknInformationNote(ETrue);
					note->ExecuteLD(*noteText);
					CleanupStack::PopAndDestroy(noteText);
					}

				ReadSettingsFromModelL(*iAppUi.GetModel());
				(*iSettingItemList->SettingItemArray())[aIndex]->LoadL();

				iSettingItemList->CAknSettingItemList::EditItemL(aIndex, aCalledFromMenu);
				(*iSettingItemList->SettingItemArray())[aIndex]->StoreL();
				}
			}
		break;

	default:
		break;
		}

	WriteSettingsToModelL(*iAppUi.GetModel());

	switch (aIndex)
		{
	case ESettingsTriggerKey:
		iAppUi.RestartWatchingKeyEventL(iAppUi.GetModel()->TriggerKeyScanCode());
		break;

	case ESettingsTriggerEvent:
		iAppUi.RestartWatchingSystemEventL(iAppUi.GetModel()->TriggerSystemEvent());
		break;

	default:
		break;
		}
	}

CGetPixelsSettingItemList::CGetPixelsSettingItemList(MGetPixelsSettingItemListObserver& aObserver, TGetPixelsSettings& aSettings) :
	iObserver(aObserver),
	iSettings(aSettings)
	{
	}

void CGetPixelsSettingItemList::SizeChanged(void)
	{
	if (ListBox() != NULL)
		{
		ListBox()->SetRect(Rect());
		}
	}

CAknSettingItem* CGetPixelsSettingItemList::CreateSettingItemL(TInt aIdentifier)
	{
	CAknSettingItem* settingItem = NULL;

	switch (aIdentifier)
		{
	case ESettingsImageFormat:
		settingItem = new(ELeave) CAknEnumeratedTextPopupSettingItem(aIdentifier, iSettings.iImageFormat);
		break;

	case ESettingsImageSetting:
		settingItem = new(ELeave) CAknBigSettingItemBase(aIdentifier);
		break;

	case ESettingsSaveLocation:
		settingItem = new(ELeave) CAknMemorySelectionSettingItem(aIdentifier, iSettings.iSaveLocation);
		break;

	case ESettingsSavedDirectoryName:
		settingItem = new(ELeave) CAknTextSettingItem(aIdentifier, iSettings.iSavedDirectoryName);
		settingItem->SetSettingPageFlags(settingItem->SettingPageFlags() | CAknTextSettingPage::EZeroLengthAllowed);
		break;

	case ESettingsSavedFileName:
		settingItem = new(ELeave) CAknTextSettingItem(aIdentifier, iSettings.iSavedFileName);
		break;

	case ESettingsTriggerKey:
		settingItem = new(ELeave) CAknEnumeratedTextPopupSettingItem(aIdentifier, iSettings.iTriggerKey);
		break;

	case ESettingsTriggerEvent:
		settingItem = new(ELeave) CAknEnumeratedTextPopupSettingItem(aIdentifier, iSettings.iTriggerEvent);
		break;

	case ESettingsDelayTime:
		settingItem = new(ELeave) CAknSliderSettingItem(aIdentifier, iSettings.iDelayTime);
		break;

	case ESettingsConfirmationNote:
		settingItem = new(ELeave) CAknBinaryPopupSettingItem(aIdentifier, iSettings.iConfirmationNote);
		break;

	case ESettingsVibrationNotification:
		settingItem = new(ELeave) CAknBinaryPopupSettingItem(aIdentifier, iSettings.iVibrationNotification);
		break;

	default:
		MY_ASSERT(EFalse);
		break;
		}

	return settingItem;
	}

void CGetPixelsSettingItemList::EditItemL(TInt aIndex, TBool aCalledFromMenu)
	{
	CAknSettingItemList::EditItemL(aIndex, aCalledFromMenu);
	(*SettingItemArray())[aIndex]->StoreL();

	iObserver.NotifyEditItemL(aIndex, aCalledFromMenu);
	}
