/**
 *	@file	GetPixelsUtilities.cpp
 *	@author	ENDO
 */

#include <e32base.h>
#include <f32file.h>
#include <imageconversion.h>	// for UIDs.

#include <pathinfo.h>	// for PathInfo.

#include "GetPixelsUtilities.h"
#include "MyAssert.h"

void GetPixelsUtilities::GetSavedFilePathL(TDes& aFilePath, const TDesC& aDriveName, const TDesC& aDirectoryName, const TDesC& aFileName, const TDesC& aExtName)
	{
	TFileName* baseFilePath = new(ELeave) TFileName;
	CleanupStack::PushL(baseFilePath);
	TFileName* extractedFileName = new(ELeave) TFileName;
	CleanupStack::PushL(extractedFileName);

	// drive name
	baseFilePath->Append(aDriveName);

	// image path
	MY_ASSERT(PathInfo::ImagesPath().Length() <= baseFilePath->MaxLength() - baseFilePath->Length());
	baseFilePath->Append(PathInfo::ImagesPath());

	// file name
		{
		TTime currentTime;
		currentTime.HomeTime();

		currentTime.FormatL(*extractedFileName, aFileName);
		if (extractedFileName->MaxLength() < extractedFileName->Length() + aExtName.Length())
			{
			User::Leave(KErrNoMemory);
			}
		}

	// ext name
	extractedFileName->Append(aExtName);

	// directory name
		{
		TParse parser;
		User::LeaveIfError(parser.Set(*extractedFileName, baseFilePath, NULL));

		if (aDirectoryName.Length() > 0)
			{
			User::LeaveIfError(parser.AddDir(aDirectoryName));
			}

		// full path
		aFilePath = parser.FullName();
		}

	CleanupStack::PopAndDestroy(extractedFileName);
	extractedFileName = NULL;
	CleanupStack::PopAndDestroy(baseFilePath);
	baseFilePath = NULL;
	}

const TDesC& GetPixelsUtilities::ExtNameFromUid(const TUid& aImageTypeUid)
	{
	_LIT(KExtNamePng, ".png");
	_LIT(KExtNameBmp, ".bmp");
	_LIT(KExtNameMbm, ".mbm");
	_LIT(KExtNameJpg, ".jpg");

	if (aImageTypeUid == KImageTypePNGUid)
		{
		return KExtNamePng();
		}
	else if (aImageTypeUid == KImageTypeBMPUid)
		{
		return KExtNameBmp();
		}
	else if (aImageTypeUid == KImageTypeMBMUid)
		{
		return KExtNameMbm();
		}
	else if (aImageTypeUid == KImageTypeJPGUid)
		{
		return KExtNameJpg();
		}

	return KNullDesC();
	}
