/**
 *	@file	ImageSaver.cpp
 *	@author	ENDO
 */

#include <e32base.h>
#include <imageconversion.h>	// for ICL.

#include "ImageSaver.h"

CImageSaver* CImageSaver::NewL(RFs& aFs, MImageSaverObserver& aObserver)
	{
	CImageSaver* self = new(ELeave) CImageSaver(aFs, aObserver);
	CleanupStack::PushL(self);
	self->ConstructL();
	CleanupStack::Pop(self);

	return self;
	}

CImageSaver::CImageSaver(RFs& aFs, MImageSaverObserver& aObserver) :
	CActive(EPriorityStandard),
	iFs(aFs),
	iObserver(aObserver)
	{
	}

void CImageSaver::ConstructL(void)
	{
	ResetFrameImageDataL();
	CActiveScheduler::Add(this);
	}

CImageSaver::~CImageSaver()
	{
	Cancel();

	delete iFrameImageData;
	delete iImageEncoder;
	}

void CImageSaver::SaveFileL(const CFbsBitmap& aBitmap, const TDesC& aFileName, TBool aEnableThread, TUid aImageType, TUid aImageSubType, TUid aEncoderUid)
	{
	if (IsActive())
		{
		User::Leave(KErrInUse);
		}

	delete iImageEncoder;
	iImageEncoder = NULL;
	iImageEncoder = CImageEncoder::FileNewL(iFs, aFileName, (aEnableThread) ? CImageEncoder::EOptionAlwaysThread : CImageEncoder::EOptionNone, aImageType, aImageSubType, aEncoderUid);

	iImageEncoder->Convert(&iStatus, aBitmap, iFrameImageData);
	SetActive();
	}

void CImageSaver::ResetFrameImageDataL(void)
	{
	CFrameImageData* newFrameImageData = CFrameImageData::NewL();

	delete iFrameImageData;
	iFrameImageData = newFrameImageData;
	}

void CImageSaver::RunL(void)
	{
	iObserver.NotifyCompletion(iStatus.Int());
	}

void CImageSaver::DoCancel(void)
	{
	if (iImageEncoder != NULL)
		{
		iImageEncoder->Cancel();
		}
	}
