/**
 *	@file	ScreenCaptor.cpp
 *	@author	ENDO
 */

#include <e32base.h>
#include <w32std.h>
#include <bitdev.h>

#include "ScreenCaptor.h"

CScreenCaptor* CScreenCaptor::NewL(CWsScreenDevice& aScreenDevice)
	{
	CScreenCaptor* self = CScreenCaptor::NewLC(aScreenDevice);
	CleanupStack::Pop(self);

	return self;
	}

CScreenCaptor::CScreenCaptor(CWsScreenDevice& aScreenDevice) :
	iScreenDevice(aScreenDevice),
	iSize(aScreenDevice.SizeInPixels()),
	iDisplayMode(aScreenDevice.DisplayMode())
	{
	}

CScreenCaptor* CScreenCaptor::NewLC(CWsScreenDevice& aScreenDevice)
	{
	CScreenCaptor* self = new(ELeave) CScreenCaptor(aScreenDevice);
	CleanupStack::PushL(self);
	self->ConstructL();

	return self;
	}

CScreenCaptor::~CScreenCaptor()
	{
	delete iBitmap;
	}

void CScreenCaptor::ConstructL(void)
	{
	iBitmap = new(ELeave) CFbsBitmap;
	User::LeaveIfError(iBitmap->Create(iSize, iDisplayMode));
	}

void CScreenCaptor::Capture(void)
	{
	iScreenDevice.CopyScreenToBitmap(iBitmap);
	}

const CFbsBitmap* CScreenCaptor::CapturedBitmap(void)
	{
	return iBitmap;
	}
