/**
 *	@file	SystemEventWatcher.cpp
 *	@author	ENDO
 */

#include <e32base.h>

#include "SystemEventWatcher.h"

CSystemEventWatcher* CSystemEventWatcher::NewL(MSystemEventObserver& aObserver)
	{
	CSystemEventWatcher* self = new(ELeave) CSystemEventWatcher(aObserver);
	CleanupStack::PushL(self);
	self->ConstructL();
	CleanupStack::Pop(self);

	return self;
	}

CSystemEventWatcher::CSystemEventWatcher(MSystemEventObserver& aObserver) :
	CActive(EPriorityStandard),
	iObserver(aObserver)
	{
	}

void CSystemEventWatcher::ConstructL(void)
	{
	User::LeaveIfError(iSystemAgent.Connect());
	CActiveScheduler::Add(this);
	}

CSystemEventWatcher::~CSystemEventWatcher()
	{
	Cancel();
	iSystemAgent.Close();
	}

void CSystemEventWatcher::StartL(TUid aUid)
	{
	iSysAgentEvent.SetRequestStatus(iStatus);
	iSysAgentEvent.SetUid(aUid); 
	iSystemAgent.NotifyOnEvent(iSysAgentEvent);
	SetActive();
	}

void CSystemEventWatcher::RunL(void)
	{
	iObserver.NotifySystemEvent(iSysAgentEvent);

    iSystemAgent.NotifyOnEvent(iSysAgentEvent);
	SetActive();
	}

void CSystemEventWatcher::DoCancel(void)
	{
	iSystemAgent.NotifyEventCancel();
	}
